package com.ruoyi.system.service;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.communityNews.CommentLikes;

import java.util.List;

/**
 * 社区资讯点赞Service接口
 * 
 * @author boman
 * @date 2025-02-25
 */
public interface ICommentLikesService 
{
    /**
     * 查询社区资讯点赞
     * 
     * @param likesId 社区资讯点赞主键
     * @return 社区资讯点赞
     */
    public CommentLikes selectCommentLikesByLikesId(Long likesId);

    /**
     * 查询社区资讯点赞列表
     * 
     * @param commentLikes 社区资讯点赞
     * @return 社区资讯点赞集合
     */
    public List<CommentLikes> selectCommentLikesList(CommentLikes commentLikes);

    /**
     * 新增社区资讯点赞
     * 
     * @param commentLikes 社区资讯点赞
     * @return 结果
     */
    public int insertCommentLikes(CommentLikes commentLikes);

    /**
     * 修改社区资讯点赞
     * 
     * @param commentLikes 社区资讯点赞
     * @return 结果
     */
    public int updateCommentLikes(CommentLikes commentLikes);

    /**
     * 批量删除社区资讯点赞
     * 
     * @param likesIds 需要删除的社区资讯点赞主键集合
     * @return 结果
     */
    public int deleteCommentLikesByLikesIds(Long[] likesIds);

    /**
     * 删除社区资讯点赞信息
     * 
     * @param likesId 社区资讯点赞主键
     * @return 结果
     */
    public int deleteCommentLikesByLikesId(Long likesId);

    /**
     * 进行点赞操作
     */
    public AjaxResult giveTheThumbs(CommentLikes commentLikes);
}
